ScanResult class

Represents the result of a scan

Constructors

ScanResult({ResultType type = ResultType.Barcode, String rawContent = '', BarcodeFormat format = BarcodeFormat.unknown, String formatNote = ''})
Creates a new scan result

Properties

format → BarcodeFormat
The barcode format
final
formatNote → String
If the format is unknown, this field holds additional information
final
hashCode → int
The hash code for this object.
no setterinherited
rawContent → String
The barcode itself if the result type is barcode. If the result type is error it contains the error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ResultType
Represents the type of the result
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited